OC.L10N.register(
    "calendar",
    {
    "Calendar" : "კალენდარი",
    "%s has published the calendar »%s«" : "%s მომხმარებელმა გამოაქვეყნა კალენდარი »%s«",
    "Hello," : "გამარჯობა,",
    "We wanted to inform you that %s has published the calendar »%s«." : "გვსურს შეგატყობინოთ, რომ %s მომხმარებელმა გამოაქყვენა კალენდარი »%s«.",
    "Open »%s«" : "გახნსნა »%s«",
    "Cheers!" : "წარმატებები!",
    "Recipient" : "მიმღები",
    "Too many redirects. Aborting ..." : "ზედმეტად ბევრი გადამისამართება. შეწყვეტა ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "დისტანციურმა სერვერმა არ მოგვანიჭა წვდომა კალენდარზე (HTTP {%s} შეცდომა)",
    "Error connecting to remote server" : "შეცდომა დისტანციურ სერვერთან კავშირისას",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "შეცდომა დისტანციური სერვერისგან რესურსის მოთხოვნისას. ეს შეიძლება გამოწვეული იყოს არასწორი სერტიფიკატით.",
    "Error requesting resource on remote server" : "შეცდომა დისტანციური სერვერისგან რესურსის მოთხოვნისას",
    "Individual" : "ინდივიდუალი",
    "Group" : "ჯგუფი",
    "Resource" : "რესურსი",
    "Room" : "ოთახი",
    "Unknown" : "უცნობი",
    "Required" : "სავალდებულო",
    "Optional" : "არასავალდებულო",
    "Does not attend" : "არ ესწრება",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "თქვენ იმყოფებით ამოუცნობი დროის სარტყელში ({tz}), ბრუნდება UTC-ზე",
    "Please create a calendar first." : "გთხოვთ ჯერ შექმნათ კალენდარი.",
    "New event" : "ახალი მოვლენა",
    "CalDAV address for clients" : "CalDAV მისამართ კლიენტისთვის",
    "Some events in this calendar are broken. Please check the JS console for more info." : "გარკვეული მოვლენები კალენდარში გაფუჭებულია. დამატებითი ინფორმაციისთვის გთხოვთ იხილოთ JS კონსოლი.",
    "Share Calendar" : "კალენდარის გაზიარება",
    "Shared" : "გაზიარებული",
    "Could not save WebCal-calendar" : "WebCal-კალენდრის შენახვა ვერ მოხერხდა",
    "WebDAV address for subscriptions" : "WebDAV მისამართი გამოწერებისთვის",
    "Email sent." : "ელ-წერილი გაიგზავნა.",
    "Could not send your email." : "თქვენი ელ-წერილის გაგზავნა ვერ მოხერხდა.",
    "group" : "ჯგუფი",
    "Details" : "დეტლაები",
    "Attendees" : "დამსწრეები",
    "Reminders" : "შემახსენებლები",
    "Repeating" : "გამეორება",
    "When shared show full event" : "როდესაც გაზიარებულია გამოჩნდეს სრული მოვლენა",
    "When shared show only busy" : "როდესაც გაზიარებულია გამოჩნდეს მხოლოდ დაკავებული",
    "When shared hide this event" : "როდესაც გაზიარებულია არ გამოჩნდეს ეს მოვლენა",
    "Confirmed" : "დადასტურებლია",
    "Tentative" : "საცდელი",
    "Cancelled" : "უარყოფილია",
    "Please add a title." : "გთხოვთ დაამატოთ სახელწოდება.",
    "Please select a calendar." : "გთოხვთ აირჩიოთ კალენდარი.",
    "The event can not end before it starts." : "მოვლენა ვერ დამთავრდება მის დაწყებამდე.",
    "Global" : "გლობალური",
    "None" : "არა",
    "Every day" : "ყოველდღიური",
    "Every week" : "ყოველკვირეული",
    "Every month" : "ყოველთვიური",
    "Every year" : "ყოველწლიური",
    "never" : "არასდროს",
    "after" : "შემდეგ",
    "How about getting started by importing some calendars?" : "რას იტყოდით დაიწყოთ კალენდრების იმპორტით?",
    "At time of event" : "მოვლენის დროს",
    "5 minutes before" : "5 წუთით ადრე",
    "10 minutes before" : "10 წუთით ადრე",
    "15 minutes before" : "15 წუდით ადრე",
    "30 minutes before" : "30 წუთით ადრე",
    "1 hour before" : "1 საათით ადრე",
    "2 hours before" : "2 საათით ადრე",
    "Custom" : "ინდივიდუალური",
    "Audio" : "აუდიო",
    "Email" : "ელ-ფოსტა",
    "Pop-up" : "Pop-up-ი",
    "sec" : "წმ",
    "min" : "წთ",
    "hours" : "საათი",
    "days" : "დღე",
    "week" : "კვირა",
    "before" : "მდე",
    "start" : "დასაწყისი",
    "end" : "დასასრული",
    "Editing reminders of unknown type not supported." : "ამოუცნობი სახეობის შემახსენებლების შეცვლის მხარდაჭერა არაა.",
    "Week {number} of {year}" : "კვირა {number} {year}-დან",
    "Successfully imported {imported} objects" : "წარმატებით დაიმპორტდა {imported} ობიექტი",
    "Imported {imported} out of {all}, skipped one duplicate" : "დაიმპორტდა {imported} სულ {all}-დან, გამოტოვებულ იქნა ერთი დუბლიკატი",
    "Imported {imported} out of {all}, one failure" : "დაიმპორტდა {imported} სულ {all}-დან, ერთი წარუმატებლობა",
    "Imported {imported} out of {all}, {errors} failures" : "დაიმპორტდა {imported} სულ {all}-დან, {errors} წარუმატებლობა",
    "Imported {imported} out of {all}, skipped {duplicates} duplicates" : "დაიმპორტდა {imported} სულ {all}-დან, გამოტოვებულ იქნა {duplicates} დუბლიკატი",
    "Imported {imported} out of {all}, {errors} failures, skipped {duplicates} duplicates" : "დაიმპორტდა {imported} სულ {all}, {errors} წარუმატებლობა, გამოტოვებულ იქნა {duplicates} დუბლიკატი",
    "Audio alarm {time} before the event starts" : "აუდიო განგაში მოვლენის დაწყებამდე {time}-ით ადრე",
    "Pop-up {time} before the event starts" : "პოპ-აპ მოვლენის დაწყებამდე {time}-ით ადრე",
    "Email {time} before the event starts" : "ელ-წერილი მოვლენის დაწყებამდე {time}-ით ადრე",
    "None {time} before the event starts" : "არც ერთი მოვლენის დაწყებამდე {time}-ით ადრე",
    "{type} {time} before the event starts" : "{type} {time} სანამ მოვლენა დაიწყება",
    "Audio alarm {time} before the event ends" : "აუდიო განგაში მოვლენის დასრულებამდე {time}-ით ადრე",
    "Pop-up {time} before the event ends" : "პოპ-აპ მოვლენის დასრულებამდე {time}-ით ადრე",
    "Email {time} before the event ends" : "ელ-წერილი მოვლენის დასრულებამდე {time}-ით ადრე",
    "None {time} before the event ends" : "არც ერთი მოვლენის დასრულებამდე {time}-ით ადრე",
    "{type} {time} before the event ends" : "{type} {time} სანამ მოვლენა დასრულდება",
    "Audio alarm {time} after the event starts" : "აუდიო განგაში მოვლენის დაწყების შემდეგ {time}-ით",
    "Pop-up {time} after the event starts" : "პოპ-აპ მოვლენის დაწყების შემდეგ {time}-ით",
    "Email {time} after the event starts" : "ელ-წერილი მოვლენის დაწყების შემდეგ {time}-ით",
    "None {time} after the event starts" : "არც ერთი მოვლენის დაწყების შემდეგ {time}-ით",
    "{type} {time} after the event starts" : "{type} {time} რაც მოვლენა დაიწყება",
    "Audio alarm {time} after the event ends" : "აუდიო განგაში მოვლენის დასრულების შემდეგ {time}-ით",
    "Pop-up {time} after the event ends" : "პოპ-აპ მოვლენის დასრულების შემდეგ {time}-ით",
    "Email {time} after the event ends" : "ელ-წერილი მოვლენის დასრულების შემდეგ {time}-ით",
    "None {time} after the event ends" : "არც ერთი მოვლენის დასრულების შემდეგ {time}-ით",
    "{type} {time} after the event ends" : "{type} {time} რაც მოვლენა დასრულდება",
    "Audio alarm at the event's start" : "მოვლენის დაწყებისას აუდიო განგაში",
    "Pop-up at the event's start" : "პოპ-აპი მოვლენის დაწყებისას",
    "Email at the event's start" : "ელ-წერილი მოვლენის დაწყებისას",
    "None at the event's start" : "არც ერთი მოვლენის დაწყებისას",
    "{type} at the event's start" : "{type} მოვლენის დაწყებისას",
    "Audio alarm at the event's end" : "აუდიო განგაში მოვლენის დასრულებისას",
    "Pop-up at the event's end" : "პოპ-აპ მოვლენის დასრულებისას",
    "Email at the event's end" : "ელ-წერილი მოვლენის დასრულებისას",
    "None at the event's end" : "არც ერთი მოვლენის დასრულებისას",
    "{type} at the event's end" : "{type} მოვლენის დასრულებისას",
    "Audio alarm at {time}" : "აუდიო განგაში დროზე {time}",
    "Pop-up at {time}" : "პოპ-აპი დროზე {time}",
    "Email at {time}" : "ელ-წერილი დროზე {time}",
    "None at {time}" : "არაფერი დროზე {time}",
    "{type} at {time}" : "{type} at {time}",
    "{calendar} shared by {owner}" : "{calendar} გააზიარა მფლობელმა {owner}",
    "Please enter a valid WebCal-URL" : "გთხოვთ შეიყვანოთ მართებული WebCal მისამართი",
    "Severe error in webcal proxy. Please contact administrator for more information." : "მძიმე შეცდომა WebCal proxy-ში. დამატებითი ინფორმაციისთვის გთხოვთ დაუკავშირდეთ ადმინისტრატორს.",
    "Title of the Event" : "მოვლენის სახელი",
    "Starts" : "იწყება",
    "Ends" : "მთავრდება",
    "All day Event" : "მთელი დღის მოვლენა",
    "Delete" : "წაშლა",
    "Cancel" : "უარყოფა",
    "More ..." : "მეტი ...",
    "Create" : "შექმნა",
    "Update" : "განახლება",
    "Close" : "დახურვა",
    "Location" : "ადგილმდებარეობა",
    "Description" : "გვერდის დახასიათება",
    "Event status" : "მოვლენის სტატუსი",
    "Visibility when sharing" : "ხილვადობა გაზიარებისას",
    "Export" : "ექსპორტი",
    "%s has published the calendar %s" : "%s მომხმარებელმა გამოაქყვეყნა კალენდარი %s",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "გვსურს გამცნობოთ %s მომხმარებელმა გამოაქვეყნა კალენდარი {boldstart}%s{boldend}.",
    "Click here to access it" : "წვდომისთვის დააჭირეთ აქ",
    "We wanted to inform you that %s has published the calendar %s." : "გვსურს გამცნობოთ %s მომხმარებელმა გამოაქვეყნა კალენდარი %s.",
    "Click on the link below to access it" : "წვდომისთვის დააჭირეთ ქვემოთ მოცემულ ბმულს",
    "Day" : "დღე",
    "Week" : "კვირა",
    "Month" : "თვე",
    "Today" : "დღეს",
    "More" : "უფრო მეტი",
    "Edit" : "რედაქტირება",
    "Link" : "ბმული",
    "iCal link" : "iCal ბმული",
    "Download" : "ჩამოტვირთვა",
    "Share with users or groups" : "გაუზიარეთ მოხმარებლებს ან ჯგუფებს",
    "can edit" : "შეგიძლია შეცვლა",
    "Share link" : "ბმულის გაზიარება",
    "Public access" : "საზოგადო წვდომა",
    "Email link to person" : "გაუგზავნეთ ბმული პიროვნებას",
    "Send" : "გაგზავნა",
    "New Calendar" : "ახალი კალენდარი",
    "Name" : "სახელი",
    "New Subscription" : "ახალი გამოწერა",
    "Go back" : "უკან დაბრუნება",
    "Go forward" : "წინ წასვლა",
    "Calendar does not exist" : "კალენდარი არ არსებობს",
    "Maybe you got a wrong link or the calendar was unshared?" : "იქნებ მიიღეთ არასწორი ბმული ან კალენდარი არ იყო გაზიარებული?",
    "Edit event" : "მოვლენის ცვლილება",
    "Delete Event" : "მოვლენის გაუქმება",
    "Save Event" : "მოვლენის შენახვა",
    "Time" : "დრო",
    "Type" : "სახეობა",
    "Relative" : "ფარდობითი",
    "Absolute" : "აბსოლუტური",
    "Repeat" : "გამეორება",
    "times every" : "დროს ყველა",
    "Email reminders have not been implemented in the CalDAV server yet, so none will be sent." : "ელ-ფოსტის შემახსენებლები ჯერ CalDAV სერვერზე არ შემოღებულა, ასე რომ არაფერი გაიგზავნება.",
    "Add" : "დამატება",
    "Email address of attendee" : "დამსწრების ელ-ფოსტის მისამართი",
    "Please add your email address in the personal settings in order to add attendees." : "დამსწრეების დასამატებლად გთხოვთ პირად პარამეტრებში დაამატოთ თქვენი ელ-ფოსტის მისამართი.",
    "from" : "დან",
    "to" : "ვის",
    "This event's repeating rule is not supported yet." : "ამ მოვლენის გამეორებითი წესი ჯერ არაა მხარდაჭერილი.",
    "Support for advanced rules will be added with subsequent updates." : "დამატებითი წესების მხარდაჭერა დამატებულ იქნება შემდგომ განახლებებში.",
    "Reset repeating rule" : "განმეორების წესების საწყის მდგომარეობაში დაბრუნება",
    "Repeat every ..." : "განმეორდეს ყოველ ...",
    "end repeat ..." : "განმეორების შეჩერება ...",
    "times" : "ჯერ",
    "Import Calendars" : "კალენდრის იმპორტი",
    "Import canceled" : "იმპორტი უარყოფილია",
    "Analyzing calendar" : "კალენდრის ანალიზი",
    "The file contains objects incompatible with the selected calendar" : "ფაილი მოიცავს არჩეულ კალენდართან არათავსებად ობიექტებს",
    "New calendar" : "ახალი კალენდარი",
    "File is empty" : "ფაილი ცარიელია",
    "Import scheduled" : "იმპორტი დაიგეგმა",
    "%s shared the calendar <strong>%s</strong> with you" : "%s მომხმარებელმა თქვენთან გააზიარა კალენდარი <strong>%s</strong>",
    "Embed" : "ჩართვა",
    "Iframe to integrate" : "საინტეგრაციო Iframe",
    "Publish URL" : "გამოქვეყნების მისამართი",
    "Settings & import" : "პარამეტრები და იმპორტი",
    "Skip simple event editor" : "მარტივი მოვლენების ედიტორის გამოტოვება",
    "Show week numbers" : "კვირის ნომრების ჩვენება",
    "Import calendar" : "კალენდრის იმპორტი",
    "No Calendars selected for import" : "იმპორტისთვის კალენდარი არაა არჩეული",
    "Primary CalDAV address" : "მთავარი CalDAV მისამართი",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV მისამართი",
    "Subscribe" : "გამოწერა"
},
"nplurals=1; plural=0;");
